'use strict';
import React, { Component } from 'react';
import {
    AppRegistry,
    StyleSheet,
    WebView,
    View, AsyncStorage
} from 'react-native';
import { Actions } from 'react-native-router-flux';
import * as Titles from '../titles';
import * as UIA from '../actions/uiActions';
import * as Common from '../common';

import {
    Container,
    Header,
    Footer,
    FooterTab,
    Body,
    Button,
    Content,
    List,
    ListItem,
    Text
} from 'native-base';
// Change these to reflect
export default class RedScreenComponent extends Component {
    constructor(props) {
        super(props);
        this.state = {
            objectValue: null
        };
    }
    componentDidMount() {
        var me = this;
        me.props.getUIDefinition(me.props.objectType);
        if (me.props.id) {
            var id = me.props.id;
            me.props.getRedObject(me.props.objectType, id, obj => {
                if (obj) {
                    me.setState({ objectValue: obj });
                }
            });
        }
        else {
            me.props.getDefaultRedObject(me.props.objectType, obj => {
                if (obj) {
                    me.setState({ objectValue: obj })
                }
            })
        }
    }
    getFooter() {
        var me = this;
        var result = null;
        var { mode } = me.props;
        var onCreate = me.props.onCreate
        switch (mode) {
            case UIA.MODE.CREATE:
                result = (
                    <Footer>
                        <FooterTab>
                            <Button onPress={Actions.pop}>
                                <Text>{Titles.Back}</Text>
                            </Button>
                            <Button onPress={() => {
                                me.props.createRedObject(me.props.objectType, me.state.objectValue, value => {
                                    if (onCreate) {
                                        onCreate(value);
                                    }
                                    if (!me.props.skipPopOnCreate) {
                                        Actions.pop();
                                    }
                                }, error => {
                                    if (me.props.onError) {
                                        me.props.onError(error);
                                    }
                                });
                            }}>
                                <Text>{Titles.Create}</Text>
                            </Button>
                        </FooterTab>
                    </Footer>
                );
                break;
            case UIA.MODE.UPDATE:
                result = (
                    <Footer>
                        <FooterTab>
                            <Button onPress={Actions.pop}>
                                <Text>{Titles.Back}</Text>
                            </Button>
                            <Button onPress={() => {
                                me.props.updateRedObject(me.props.objectType, me.props.id, me.state.objectValue);
                            }}>
                                <Text>{Titles.Update}</Text>
                            </Button>
                        </FooterTab>
                    </Footer>
                );
                break;
            case UIA.MODE.READ:
                result = (
                    <Footer>
                        <FooterTab>
                            <Button onPress={Actions.pop}>
                                <Text>{Titles.Back}</Text>
                            </Button>
                            <Button onPress={() => {
                                me.setState({ edit: !me.state.edit })
                            }}>
                                <Text>{me.state.edit ? Titles.Edit : Titles.Cancel}</Text>
                            </Button>
                        </FooterTab>
                    </Footer>
                );
                break;
            case UIA.MODE.DELETE:
                result = (
                    <Footer>
                        <FooterTab>
                            <Button onPress={Actions.pop}>
                                <Text>{Titles.Back}</Text>
                            </Button>
                            <Button onPress={() => {
                                me.props.deleteRedObject(me.props.objectType, me.props.id);
                            }}>
                                <Text>{Titles.Delete}</Text>
                            </Button>
                        </FooterTab>
                    </Footer>
                );
                break;
        }

        return result;
    }
    render() {
        var me = this;
        var { state } = me.props;
        var ui = UIA.GetC(state, UIA.UI_DEFINIONS, me.props.objectType);
        var footer = me.getFooter();
        return (
            <Container>
                <Header>
                    {Common.BackButton()}
                    {Common.HeaderTitle(me.props.title)}
                </Header>
                <Content>
                    {ui ? Common.CommonUi(ui, () => {
                        return me.state.objectValue;
                    }, (name, value) => {
                        var objectValue = Object.assign({}, me.state.objectValue, name ? { [name]: value } : value);
                        me.setState({ objectValue })
                    }, me.props.mode === UIA.MODE.READ && !me.state.edit) : null}
                </Content>
                {footer}
            </Container>
        )
    }
}

const styles = ({
});
